import React, { useCallback } from 'react';
import { TouchableOpacity, Text, StyleSheet } from 'react-native';

const Cell = _ref => {
  let {
    onPress,
    config,
    ...props
  } = _ref;
  const handleCellPress = useCallback(() => {
    onPress === null || onPress === void 0 ? void 0 : onPress(config.value);
  }, [onPress, config.value]);
  const margin = props.margin !== undefined ? props.margin / 2 : 0;
  const width = props.baseSize !== undefined ? props.baseSize * config.size + margin * 2 * (config.size - 1) : undefined;
  return /*#__PURE__*/React.createElement(TouchableOpacity, {
    style: [styles.cell, {
      height: props.baseSize,
      width,
      minWidth: width,
      marginVertical: margin,
      marginHorizontal: margin
    }, props.keyStyle, config.keyStyle],
    onPress: handleCellPress
  }, /*#__PURE__*/React.createElement(Text, {
    style: [styles.text, {
      fontSize: props.fontSize
    }, props.textStyle, config.textStyle]
  }, config.display || config.value));
};

const styles = StyleSheet.create({
  cell: {
    borderWidth: 1,
    backgroundColor: 'lightgray',
    flex: 0,
    justifyContent: 'center'
  },
  text: {
    color: '#000',
    textAlign: 'center'
  }
});
export default Cell;
//# sourceMappingURL=cell.js.map