import * as constants from './constants';
export const createKeyConfigFromString = (config, input) => {
  const match = constants.sizeRegex.exec(input);
  let value = input;
  let size = 1;

  if (match !== null && match !== void 0 && match[1]) {
    size = parseFloat(match[1]);
    value = value.replace(match[0], '');
  }

  return { ...constants.DEFAULT_KEY_CONFIG,
    value,
    size,
    isTrigger: constants.triggerRegex.test(value),
    display: getDisplayNameFromConfig(config, value)
  };
};
export const getDisplayNameFromConfig = (config, name) => {
  var _config$displayOption, _config$displayOption2;

  return (_config$displayOption = config.displayOptions) === null || _config$displayOption === void 0 ? void 0 : (_config$displayOption2 = _config$displayOption.display) === null || _config$displayOption2 === void 0 ? void 0 : _config$displayOption2[name];
};
export const getLongestRow = layout => {
  return layout.reduce((l, c) => {
    const size = getRowLength(c);
    return size > l ? size : l;
  }, 0);
};
export const getLongestWord = (config, layout) => {
  return layout.reduce((longest, current) => {
    const longestWord = current.reduce((l, c) => {
      var _getDisplayNameFromCo;

      // Local display value overrides global option
      if (c.display) {
        return l < c.display.length ? c.display.length : l;
      }

      const val = ((_getDisplayNameFromCo = getDisplayNameFromConfig(config, c.value)) === null || _getDisplayNameFromCo === void 0 ? void 0 : _getDisplayNameFromCo.length) || c.value.length;
      return l < val ? val : l;
    }, 0);
    return longestWord < longest ? longest : longestWord;
  }, 0);
};
export const getRowLength = row => {
  return row.reduce((a, v) => a + v.size, 0);
};
export const createLayoutConfigArray = config => {
  const l = {};
  Object.keys(config.layouts).forEach(key => {
    l[key] = config.layouts[key].map(row => {
      return row.reduce((list, value) => {
        if (typeof value === 'string') {
          list.push(createKeyConfigFromString(config, value));
        } else {
          list.push({ ...constants.DEFAULT_KEY_CONFIG,
            ...value,
            display: value.display || getDisplayNameFromConfig(config, value.value)
          });
        }

        return list;
      }, []);
    });
  });
  return l;
};
export const calculateCellSize = (config, layout, area, measure) => {
  var _config$displayOption3, _config$displayOption4;

  if (!area.width || !area.height) {
    return {
      cellSize: undefined,
      cellMargin: undefined
    };
  }

  const longest = getLongestRow(layout);
  const margin = ((_config$displayOption3 = (_config$displayOption4 = config.displayOptions) === null || _config$displayOption4 === void 0 ? void 0 : _config$displayOption4.marginPercent) !== null && _config$displayOption3 !== void 0 ? _config$displayOption3 : 1) / 100;
  const marginWidth = Math.max(margin * area.width, 0);
  const marginHeight = Math.max(margin * area.height, 0);
  const maxHeight = area.height / layout.length - marginHeight / layout.length;
  const maxWidth = area.width / longest - marginWidth / longest;
  const cellSize = maxHeight > maxWidth ? maxWidth : maxHeight;
  const cellMargin = maxHeight > maxWidth ? marginWidth / longest : marginHeight / layout.length;
  const cellFontSize = calculateFontSize(measure, cellSize, getLongestWord(config, layout));
  return {
    cellSize,
    cellMargin,
    cellFontSize
  };
};
export const calculateFontSize = (measure, cellSize, longestWord) => {
  if (!measure.height || !measure.width) {
    return undefined;
  }

  if (longestWord === 1) {
    return cellSize / (measure.height / 100 * longestWord);
  }

  return cellSize / (measure.width / 100 / 1.35 * longestWord);
};
//# sourceMappingURL=utils.js.map